summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2011-03-31 23:47:01 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2011-03-31 23:50:46 -0500
commitb0525f83e1ce48ff8055036aaab194fe31f5d3da (patch)
tree89c660dd3b121de45fe5b3d8ac60f4d6e99c159c /png.h
parentee1369b853721b6d25a4cbc6ab67f848711b11cb (diff)
downloadlibpng-b0525f83e1ce48ff8055036aaab194fe31f5d3da.tar.gz
[devel] Bump to version libpng-1.5.3beta02
Diffstat (limited to 'png.h')
-rw-r--r--png.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/png.h b/png.h
index 2fe787eeb..d1dca7a18 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.3beta01 - April 1, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.3beta01 - April 1, 2011: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -150,7 +150,7 @@
* 1.5.2beta01-03 15 10502 15.so.15.2[.0]
* 1.5.2rc01-03 15 10502 15.so.15.2[.0]
* 1.5.2 15 10502 15.so.15.2[.0]
- * 1.5.3beta01 15 10503 15.so.15.3[.0]
+ * 1.5.3beta01-02 15 10503 15.so.15.3[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -182,7 +182,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.3beta01, April 1, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -300,7 +300,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.3beta01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -356,9 +356,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.3beta01"
+#define PNG_LIBPNG_VER_STRING "1.5.3beta02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.3beta01 - April 1, 2011\n"
+ " libpng version 1.5.3beta02 - April 1, 2011\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -371,7 +371,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 02
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -518,7 +518,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_3beta01;
+typedef char* png_libpng_version_1_5_3beta02;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.3beta01 - April 1, 2011
+ * libpng version 1.5.3beta02 - April 1, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.3beta01 - April 1, 2011: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.3beta02 - April 1, 2011: Glenn
* See also "Contributing Authors", below.
*
@@ -182,7 +182,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.3beta01, April 1, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.3beta02, April 1, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -300,7 +300,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.3beta01 are Y2K compliant. It is my belief that
+ * upward through 1.5.3beta02 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*